==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/CommandLineOptions/PlayListOption/translations/playlist_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>PlayListOption</name>
    <message>
        <location filename="../playlistoption.cpp" line="46"/>
        <source>Show playlist manipulation commands</source>
        <translation>Befehle zum Steuern der Wiedergabeliste anzeigen</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="60"/>
        <source>List all available playlists</source>
        <translation>Alle verfügbaren Wiedergabelisten anzeigen</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="61"/>
        <source>Show playlist content</source>
        <translation>Inhalt der Wiedergabeliste anzeigen</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="62"/>
        <source>Play track &lt;track&gt; in playlist &lt;id&gt;</source>
        <translation>Stück &lt;track&gt; aus der Wiedergabeliste &lt;id&gt; abspielen</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="63"/>
        <source>Clear playlist</source>
        <translation>Wiedergabeliste leeren</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="64"/>
        <source>Toggle playlist repeat</source>
        <translation>Wiederholung der Wiedergabeliste an/aus</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="65"/>
        <source>Toggle playlist shuffle</source>
        <translation>Zufallswiedergabe der Wiedergabeliste an/aus</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="66"/>
        <source>Show playlist options</source>
        <translation>Wiedergabelisten-Einstellungen anzeigen</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="85"/>
        <location filename="../playlistoption.cpp" line="106"/>
        <location filename="../playlistoption.cpp" line="135"/>
        <source>Invalid playlist ID</source>
        <translation>Ungültige Wiedergabenlisten-ID</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="100"/>
        <source>Invalid number of arguments</source>
        <translation>Ungültige Anzahl an Argumenten</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="123"/>
        <source>Invalid track ID</source>
        <translation>Ungültige Stück-ID</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/CommandLineOptions/PlayListOption/translations/playlist_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>PlayListOption</name>
    <message>
        <location filename="../playlistoption.cpp" line="33"/>
        <source>Show playlist manipulation commands</source>
        <translation>Befehle zum Steuern der Wiedergabeliste anzeigen</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="34"/>
        <source>List all available playlists</source>
        <translation>Alle verfügbaren Wiedergabelisten anzeigen</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="35"/>
        <source>Show playlist content</source>
        <translation>Inhalt der Wiedergabeliste anzeigen</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="36"/>
        <source>Play track &lt;track&gt; in playlist &lt;id&gt;</source>
        <translation>Titel &lt;track&gt; aus der Wiedergabeliste &lt;id&gt; abspielen</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="37"/>
        <source>Clear playlist</source>
        <translation>Wiedergabeliste leeren</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="38"/>
        <source>Toggle playlist repeat</source>
        <translation>Wiederholung der Wiedergabeliste an/aus</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="39"/>
        <source>Toggle playlist shuffle</source>
        <translation>Zufallswiedergabe der Wiedergabeliste an/aus</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="40"/>
        <source>Show playlist options</source>
        <translation>Wiedergabelisten-Einstellungen anzeigen</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="104"/>
        <location filename="../playlistoption.cpp" line="126"/>
        <location filename="../playlistoption.cpp" line="143"/>
        <source>Invalid playlist ID</source>
        <translation>Ungültige Wiedergabenlisten-ID</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="120"/>
        <source>Invalid number of arguments</source>
        <translation>Ungültige Anzahl an Argumenten</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="130"/>
        <source>Invalid track ID</source>
        <translation>Ungültige Titelkennung</translation>
    </message>
</context>
</TS>
